import django.http

__all__ = ["HttpResponseException",
           "BadRequest",
           "NotFound",
           "Forbidden",
           "NotAllowed",
           "Gone",
           "ServerError",
           "UnusualHttpMiddleware"]

class HttpResponseException(Exception):
    def __init__(self, *args, **kwargs):
        super(HttpResponseException, self).__init__(*args)
        self.response = None

class BadRequest(django.http.HttpResponseBadRequest, HttpResponseException):
    pass

class NotFound(django.http.HttpResponseNotFound, HttpResponseException):
    pass

class Forbidden(django.http.HttpResponseForbidden, HttpResponseException):
    pass

class NotAllowed(django.http.HttpResponseNotAllowed, HttpResponseException):
    pass

class Gone(django.http.HttpResponseGone, HttpResponseException):
    pass

class ServerError(django.http.HttpResponseServerError, HttpResponseException):
    pass

class UnusualHttpMiddleware(object):
    def process_exception(self, request, exception):
        if isinstance(exception, django.http.HttpResponse):
            return exception
        else:
            return None



from setuptools import setup, find_packages

setup(
    name="django-unusual",
    url="https://github.com/dvogel/django-unusual",
    version='0.1',
    packages=find_packages(),
    description="Allows django apps to raise HttpResponse objects as exceptions.",
    author="Drew Vogel",
    author_email="drewpvogel@gmail.com",
    license='BSD',
    platforms=["any"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=['django']
)
